#!/bin/sh
echo 'name: hslogger
version: 1.1.5
id: hslogger-1.1.5-13adda0b39a0331b6f8f7322430839f1

license: BSD3
copyright: Copyright (c) 2004-2011 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
stability: Stable
homepage: http://software.complete.org/hslogger
package-url:
synopsis: Versatile logging framework
description: hslogger is a logging framework for Haskell, roughly similar to
             Python'\''s logging module.
             .
             hslogger lets each log message have a priority and source be associated
             with it.  The programmer can then define global handlers that route
             or filter messages based on the priority and source.  hslogger also
             has a syslog handler built in.
category: Interfaces
author: John Goerzen
pkgpath: devel/hs-hslogger
exposed: True
exposed-modules: System.Log System.Log.Handler System.Log.Formatter
                 System.Log.Handler.Simple System.Log.Handler.Syslog
                 System.Log.Handler.Growl System.Log.Handler.Log4jXML
                 System.Log.Logger
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/hslogger-1.1.5
library-dirs: /usr/local/lib/ghc/hslogger-1.1.5
hs-libraries: HShslogger-1.1.5
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
         directory-1.1.0.2-4b2070a8941d5c76e41241a2ac457927
         mtl-2.1.2-cf6082d8d4c6758d23401302efadd028
         network-2.3.1.0-e56ec3d5abd17b7b386690bf49d424ab
         old-locale-1.0.0.4-b1d945ebea59a524cba400a524cb40aa
         process-1.1.0.1-c55e7a2b0eb5149f070b14e14bea1c83
         time-1.4-b8e1c3d423daa1e2c5470a82caf23b52
         unix-2.5.1.1-c23dadb7ccff9eeb5d1df0bd91909ca9
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-hslogger-1.1.5/html/hslogger.haddock
haddock-html: /usr/local/share/doc/hs-hslogger-1.1.5/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
